X-Git-Url: https://git.saurik.com/wxWidgets.git/blobdiff_plain/8907154c1a8a6882c6797d1f16393ddfb23e7f3a..26cdd42d2cbd99d23159ae4b4d41ae93ed23317c:/include/wx/motif/dcmemory.h?ds=sidebyside

diff --git a/include/wx/motif/dcmemory.h b/include/wx/motif/dcmemory.h
index ee0cf492ae..2ef13d6247 100644
--- a/include/wx/motif/dcmemory.h
+++ b/include/wx/motif/dcmemory.h
@@ -1,6 +1,6 @@
 /////////////////////////////////////////////////////////////////////////////
 // Name:        dcmemory.h
 // Purpose:     wxMemoryDC class
 // Author:      Julian Smart
 // Modified by:
 // Created:     17/09/98
@@ -12,27 +12,33 @@
 #ifndef _WX_DCMEMORY_H_
 #define _WX_DCMEMORY_H_
 
-#include "wx/dcclient.h"
+#include "wx/motif/dcclient.h"
 
-class WXDLLIMPEXP_CORE wxMemoryDC : public wxWindowDC
+class WXDLLIMPEXP_CORE wxMemoryDCImpl : public wxWindowDCImpl
 {
-    DECLARE_DYNAMIC_CLASS(wxMemoryDC)
-        
 public:
-    wxMemoryDC();
-    wxMemoryDC( wxDC *dc ); // Create compatible DC
-    ~wxMemoryDC();
-    
-    virtual void SelectObject( const wxBitmap& bitmap );
-    
-    void DoGetSize( int *width, int *height ) const;
-    
-    wxBitmap& GetBitmap() const { return (wxBitmap&) m_bitmap; }
-    
+    wxMemoryDCImpl(wxMemoryDC *owner) : wxWindowDCImpl(owner) { Init(); }
+    wxMemoryDCImpl(wxMemoryDC *owner, wxBitmap& bitmap)
+        : wxWindowDCImpl(owner)
+    {
+        Init();
+        DoSelect(bitmap);
+    }
+
+    wxMemoryDCImpl(wxMemoryDC *owner, wxDC *dc);
+    virtual ~wxMemoryDCImpl();
+
+    virtual void DoGetSize( int *width, int *height ) const;
+    virtual void DoSelect(const wxBitmap& bitmap);
+
 private:
     friend class wxPaintDC;
-    
-    wxBitmap  m_bitmap;
+
+    void Init();
+
+    wxBitmap m_bitmap;
+
+    DECLARE_DYNAMIC_CLASS(wxMemoryDCImpl)
 };
 
 #endif
@@ -1,6 +1,6 @@
 /////////////////////////////////////////////////////////////////////////////
-// Name:        dcmemory.h
-// Purpose:     wxMemoryDC class
+// Name:        wx/motif/dcmemory.h
+// Purpose:     wxMemoryDCImpl class
 // Author:      Julian Smart
 // Modified by: